@@ -1,10 +1,12 @@
+#!/usr/bin/env python3
+
 import argparse
 import dataclasses
 import io
 import os
 import re
 import sys
-from typing import List, Optional, TextIO
+from typing import Dict, List, Optional, TextIO, Tuple
 
 STACK = "Stack"
 
@@ -110,12 +112,12 @@ class RunData:
     prefix: str
     headerOutDir: str
     srcOutDir: str
-    type_map: dict[str, str] = dataclasses.field(default_factory=dict)
-    op_symbols: dict[str, str] = dataclasses.field(default_factory=dict)
+    type_map: Dict = dataclasses.field(default_factory=dict)  # type: Dict[str, str]
+    op_symbols: Dict = dataclasses.field(default_factory=dict)  # type: Dict[str, str]
 
 
-def read_opsymbols(opsymbols_file: str) -> dict[str, str]:
-    op_symbols: dict[str, str] = {}
+def read_opsymbols(opsymbols_file: str) -> Dict:
+    op_symbols: Dict = {}
     with open(opsymbols_file, "r", encoding="utf-8") as opf:
         for line in opf:
             # match OPSYMBOL("symname", token);
@@ -147,9 +149,9 @@ def parse_args() -> RunData:
 
 def parse_types(
     data: str, input_filename: str, input_start_line: int
-) -> tuple[dict[str, str], int]:
+) -> Tuple[Dict, int]:
     """Return (new_entries, lines_consumed)."""
-    entries: dict[str, str] = {}
+    entries: Dict = {}
     lines = data.split("\n")
     for line_no, line in enumerate(lines, start=input_start_line):
         # Remove // comments in each line
@@ -205,7 +207,7 @@ class FunctionData:
         section: str,
         prefix: str,
         function_count: int,
-        header_lines: List[str],
+        header_lines: List,
     ):
         global STACK
         md = self._pat.search(section)
@@ -341,7 +343,7 @@ def overwrite_if_changed(filename: str, new_contents: str) -> None:
         f.write(new_contents)
 
 
-def write_trans_namespace(f_out: TextIO, d: RunData, builtin: List[str]) -> None:
+def write_trans_namespace(f_out: TextIO, d: RunData, builtin: List) -> None:
     f_out.write("namespace trans {\n\n")
     f_out.write(f"void gen_{d.prefix}_venv(venv &ve)\n")
     f_out.write("{\n")
@@ -350,7 +352,7 @@ def write_trans_namespace(f_out: TextIO, d: RunData, builtin: List[str]) -> None
     f_out.write("} // namespace trans\n")
 
 
-def read_sections(filename: str) -> List[str]:
+def read_sections(filename: str) -> List:
     # Read *.in files split by form-feed + newline
     with open(filename, "rb") as f:
         # Convert to text with universal newline
@@ -373,7 +375,7 @@ def main(d: RunData) -> None:
     finalize_output(outHeaderFile, outSrcFile, header_lines)
 
 
-def read_input_sections(d: RunData) -> tuple[List[str], List[str]]:
+def read_input_sections(d: RunData) -> Tuple[List, List]:
     # Read base, prefix.in, etc., all separated by form-feed + newline
     sections_in = read_sections(os.path.join(d.srcTemplateDir, f"{d.prefix}.in"))
     sections_base = read_sections(d.runtimeBaseFile)
@@ -381,8 +383,8 @@ def read_input_sections(d: RunData) -> tuple[List[str], List[str]]:
 
 
 def process_sections(
-    d: RunData, sections_in: List[str], sections_base: List[str], outSrcFile: str
-) -> List[str]:
+    d: RunData, sections_in: List, sections_base: List, outSrcFile: str
+) -> List:
     with open(outSrcFile, "w", newline="", encoding="utf-8") as f_out:
         out_autogen = (
             f"/***** Autogenerated from {d.prefix}.in; "
@@ -436,7 +438,7 @@ def process_sections(
         f_out.write("namespace run {\n")
 
         header_lines = [out_autogen, "#pragma once\n", "namespace run {\n"]
-        builtin: List[str] = []
+        builtin: List = []
 
         # 6) read remaining lines from sections_in[3...] for function definitions
         for function_count, section in enumerate(sections_in[3:]):
@@ -469,9 +471,7 @@ def process_sections(
     return header_lines
 
 
-def finalize_output(
-    outHeaderFile: str, outSrcFile: str, header_lines: List[str]
-) -> None:
+def finalize_output(outHeaderFile: str, outSrcFile: str, header_lines: List) -> None:
     header_lines.append("}\n\n")
     overwrite_if_changed(outHeaderFile, "".join(header_lines))
 
